aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/core/util/test_log.proto
diff options
context:
space:
mode:
authorGravatar Eugene Brevdo <ebrevdo@gmail.com>2016-03-15 12:22:04 -0800
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2016-03-15 15:15:29 -0700
commit6f1acd3af3493de4cb7900629ce065d66c8c28bc (patch)
treea4fdc0cae8e1c76bcbfd78c15e7efa994777981b /tensorflow/core/util/test_log.proto
parent80159cde9ac0bba6e08d6694ece60e9ebe87235a (diff)
A few more tweaks to test_log.proto to reflect what's accessible from bazel build.
Also some updates to run_and_gather_logs. Reduce the set of tests that run_and_gather_logs_test runs to speed up the tests. Change: 117271064
Diffstat (limited to 'tensorflow/core/util/test_log.proto')
-rw-r--r--tensorflow/core/util/test_log.proto8
1 files changed, 5 insertions, 3 deletions
diff --git a/tensorflow/core/util/test_log.proto b/tensorflow/core/util/test_log.proto
index 391b76eec3..3ade562533 100644
--- a/tensorflow/core/util/test_log.proto
+++ b/tensorflow/core/util/test_log.proto
@@ -50,9 +50,8 @@ message BenchmarkEntries {
}
message BuildConfiguration {
- string mode = 1; // opt, dbg, etc
- repeated string config = 2; // asan, cuda, etc
- repeated string copts = 3; // -mavx, etc.
+ string mode = 1; // opt, dbg, etc
+ repeated string cc_flags = 2; // CC compiler flags
};
message CommitId {
@@ -60,6 +59,9 @@ message CommitId {
int64 changelist = 1;
string hash = 2;
}
+ // Hash of intermediate change between hash/changelist and what was tested.
+ // Not used if the build is from a commit without modifications.
+ string snapshot = 3;
};
message CPUInfo {